package cn.fw.hermes.common.utils.im;

import com.tls.tls_sigature.tls_sigature;
import lombok.Getter;
import java.util.Random;

/**
 * im辅助类
 *
 * @author Kurisu
 * @date 2018-09-08
 */
public class TXCloudHelper {

    private static final int EXPIRETIME = 604800;


    /**
     * 获取账号名
     *
     * @param userId 用户ID
     * @param preEnum 账号类型
     * @return
     */
    public static String getIdentifier(Long userId,PrefixEnum preEnum) {
        StringBuffer sb = new StringBuffer(preEnum.getMsg());
        sb.append(userId);
        return sb.toString();
    }

    public enum PrefixEnum {
        /**
         * 账号类型
         */
        BUSINESS(0, "bh"),
        CUSTOMER(1, "ch");
        @Getter
        private Integer code;
        @Getter
        private String msg;

        PrefixEnum(Integer code, String msg) {
            this.code = code;
            this.msg = msg;
        }
    }

    /**
     * 生成签名 默认180天
     *
     * @param identifier
     * @param expire
     * @return
     */
    public static String getSig(String identifier, Integer expire,Long appId,String privStr) {
        expire = expire == null ? EXPIRETIME : expire;
        tls_sigature.GenTLSSignatureResult result = tls_sigature.genSig(appId, identifier, expire, privStr);
        if (0 == result.urlSig.length()){
            return null;
        }
        return result.urlSig;

    }

    /**
     * @param serviceName
     * @return 获取url
     */
    public static String getUrl(String serviceName, String sig, String identifier, Long appId) {
        StringBuffer sb = new StringBuffer("https://console.tim.qq.com/v4/");
        sb.append(serviceName).append("?usersig=").append(sig);
        sb.append("&identifier=").append(identifier);
        sb.append("&sdkappid=").append(appId);
        sb.append("&contenttype=json&random=").append(randomInt());
        return sb.toString();
    }

    /**
     * 随机数
     */
    public static int randomInt() {
        Random random = new Random();
        return random.nextInt();
    }

    /**
     * @param upper 取值范围[0,upper)
     */
    public static int randomInt(int upper) {
        Random random = new Random();
        return random.nextInt(upper);
    }
}