package cn.fw.hermes.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * 发送消息的用户类型
 * 0 表示系统用户
 * 1 表示普通用户
 */
public enum BusinessTypeEnum implements IEnum<Integer> {
    /**
     * 账号业务类型
     */
    SYS_NOTICE(0, "系统消息"),
    GRADE_NOTICE(1, "评级通知"),
    /**
     * 内部通知指不需要通知栏提示的类型
     */
    INTERNAL_NOTIFICATION(2, "内部通知");


    /**
     * 值
     */
    private final Integer value;
    /**
     * 类型
     */
    @Getter
    private final String name;

    BusinessTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static BusinessTypeEnum ofValue(final Integer value) {
        for (final BusinessTypeEnum typeEnum : BusinessTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final BusinessTypeEnum typeEnum : BusinessTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }
}
